<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AddLayer</name>
    <message>
        <location filename="../AddLayerInit.js" line="+2"/>
        <source>&amp;Add Layer</source>
        <translation>Layer &amp;hinzufügen</translation>
    </message>
    <message>
        <location filename="../AddLayer.js" line="+35"/>
        <source>Layer</source>
        <translation>Layer</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Add Layer</source>
        <translation>Layer hinzufügen</translation>
    </message>
</context>
<context>
    <name>Layer</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+33"/>
        <source>Default color for new layers:</source>
        <translation>Standard Farbe für neue Layer:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Default lineweight for layer 0:</source>
        <translation>Standard Linienbreite für Layer 0:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Default color for layer 0:</source>
        <translation>Standard Farbe für Layer 0:</translation>
    </message>
    <message>
        <location line="-45"/>
        <source>Default lineweight for new layers:</source>
        <translation>Standard Linienbreite für neue Layer:</translation>
    </message>
</context>
</TS>
